Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(3916)

Unified Diff: fetch_configs/syzygy.py

Issue 1749213002: Add a Syzygy fetch config. (Closed) Base URL: https://chromium.googlesource.com/chromium/tools/depot_tools.git@master
Patch Set: Rename the DEPS file. Created 4 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: fetch_configs/syzygy.py
diff --git a/fetch_configs/infra.py b/fetch_configs/syzygy.py
similarity index 62%
copy from fetch_configs/infra.py
copy to fetch_configs/syzygy.py
index 12e5c9646a766632dffe6dc2fd4378a2bba9366c..cb1ac6e378bb9aff5947884920cbd5d732a0e571 100644
--- a/fetch_configs/infra.py
+++ b/fetch_configs/syzygy.py
@@ -1,4 +1,4 @@
-# Copyright 2014 The Chromium Authors. All rights reserved.
+# Copyright 2016 The Chromium Authors. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
# found in the LICENSE file.
@@ -9,8 +9,8 @@ import config_util # pylint: disable=F0401
# This class doesn't need an __init__ method, so we disable the warning
# pylint: disable=W0232
-class Infra(config_util.Config):
- """Basic Config class for the Infrastructure repositories."""
+class Syzygy(config_util.Config):
+ """Basic Config class for Syzygy."""
@staticmethod
def fetch_spec(_props):
@@ -19,9 +19,9 @@ class Infra(config_util.Config):
'gclient_git_spec': {
'solutions': [
{
- 'name' : 'infra',
- 'url' : 'https://chromium.googlesource.com/infra/infra.git',
- 'deps_file': '.DEPS.git',
+ 'name' : 'src',
+ 'url' : 'https://github.com/google/syzygy.git',
+ 'deps_file': 'DEPS',
'managed' : False,
}
],
@@ -30,11 +30,11 @@ class Infra(config_util.Config):
@staticmethod
def expected_root(_props):
- return 'infra'
+ return 'src'
def main(argv=None):
- return Infra().handle_args(argv)
+ return Syzygy().handle_args(argv)
if __name__ == '__main__':
« no previous file with comments | « no previous file | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698